@@ -148,14 +148,17 @@ download_data <- function(url, destdir = getwd(), timestamping = T, nc = F, verb
             timecondition = TRUE, timevalue = base::file.info(destfile)$mtime)
         hand <- curl::new_handle()
         curl::handle_setopt(hand, .list = opts)
-        tryCatch(status <- curl::curl_fetch_disk(url, path = temp.file, handle = hand), error = function(e) {
+        tryCatch(status <- curl::curl_fetch_disk(url, path = temp.file, handle = hand),
+                 error = function(e) {
           message("Download of ", 
             url, " failed. Reverting to already cached file.")
           return(destfile)
           })
+        
         if (file.info(temp.file)$size > 0) {
             file.copy(temp.file, destfile, overwrite = T)
         }
+        return(destfile)
     } else {
         message("Downloading file: ", url)
         opts <- list(verbose = verbose,
@@ -171,4 +174,5 @@ download_data <- function(url, destdir = getwd(), timestamping = T, nc = F, verb
                  error = function(e) stop("Download of ", url, " failed!"))
         return(destfile)
     }
+    return(destfile)
 }
